``neutcurve`` documentation
======================================

`neutcurve` is a Python package written by the `Bloom lab <https://research.fhcrc.org/bloom/en.html>`_ for fitting and plotting neutralization curves.

See below for information and examples of how to use this package.

Contents
----------
.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 2

   installation
   hillcurve_example
   curvefits_example
   raw_examples
   neutcurve
   package_index
   acknowledgments
